DROP TABLE IF EXISTS surveys;
CREATE TABLE surveys (
  survey_id bigint(10) NOT NULL auto_increment,
  module varchar(32) NOT NULL,
  module_key int(10) NOT NULL,
  author_id int(10) NOT NULL,
  viewer_group int(10) NOT NULL,
  creation varchar(20) NOT NULL,
  survey_option_values varchar(256) NOT NULL,
  survey_status int(1) NOT NULL,
  starts varchar(20) NOT NULL,
  ends varchar(20) NOT NULL,
  survey_image varchar(128) NOT NULL,
  comments int(1) NOT NULL,
  viewed int(10) NOT NULL,
  PRIMARY KEY  (survey_id),
  KEY module (module),
  KEY module_key (module_key),
  KEY author_id (author_id),
  KEY creation (creation),
  KEY survey_status (survey_status),
  KEY survey_image (survey_image),
  KEY ends (ends),
  KEY starts (starts),
  KEY comments (comments),
  KEY viewed (viewed),
  KEY viewer_group (viewer_group)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1;





DROP TABLE IF EXISTS surveys_blocks;
CREATE TABLE surveys_blocks (
  block_id int(3) NOT NULL auto_increment,
  position_id int(3) NOT NULL default '0',
  module_name varchar(64) NOT NULL default '0',
  block_title varchar(64) NOT NULL,
  block_status varchar(32) NOT NULL default '',
  undeletable int(1) NOT NULL default '0',
  view_order int(3) NOT NULL default '1',
  PRIMARY KEY  (block_id,position_id,block_title),
  UNIQUE KEY position_id (position_id,block_title),
  KEY module_name (module_name),
  KEY block_status (block_status,undeletable)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1;



INSERT INTO surveys_blocks VALUES(34, 2, 'content', 'frontpage', '1', 0, 1);
INSERT INTO surveys_blocks VALUES(33, 4, 'content', 'frontpage_list_latest_surveys_cols', '1', 0, 1);
INSERT INTO surveys_blocks VALUES(32, 3, 'content', 'frontpage_list_latest_surveys', '0', 0, 1);
INSERT INTO surveys_blocks VALUES(35, 0, '', '', '', 0, 4);


DROP TABLE IF EXISTS surveys_configure;
CREATE TABLE surveys_configure (
  config_id int(6) NOT NULL auto_increment,
  module_name varchar(64) NOT NULL default '',
  config_type varchar(64) NOT NULL default '0',
  config_title varchar(64) NOT NULL default '',
  config_description text NOT NULL,
  config_key varchar(128) NOT NULL default '',
  config_value varchar(128) NOT NULL default '',
  undeletable int(1) NOT NULL default '0',
  PRIMARY KEY  (config_id),
  KEY config_type (config_type),
  KEY config_key (config_key)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1;



INSERT INTO surveys_configure VALUES(1, 'surveys', 'Main Config', 'View Modus', '', 'CONT_VIEW_MOD', '2', 1);
INSERT INTO surveys_configure VALUES(2, 'surveys', 'Front Page', 'Frontpage View Modus', '', 'FP_VIEW_MODUS', '2', 1);
INSERT INTO surveys_configure VALUES(3, 'surveys', 'Front Page', 'Num of Random Survays', '', 'RANDOM_SURVEY_NUM', '5', 1);
INSERT INTO surveys_configure VALUES(10, 'surveys', 'Survay Details', 'Show Autor', '', 'SHOW_AUTHOR', '1', 1);
INSERT INTO surveys_configure VALUES(11, 'surveys', 'Survay Details', 'Show Date', '', 'SHOW_DATE', '', 1);
INSERT INTO surveys_configure VALUES(12, 'surveys', 'Survay Listing', 'Max Search Results', '', 'MAX_SRCH_RES', '5', 1);
INSERT INTO surveys_configure VALUES(17, 'surveys', 'Max/Min', 'Maximal Size Survay Image', '', 'MAX_SURVEY_IMAGE_SIZE', '100000', 1);
INSERT INTO surveys_configure VALUES(30, 'surveys', 'Pictures Upload', 'Max Survay image width', '', 'MAX_SURVEY_IMAGE_WIDTH', '200', 1);
INSERT INTO surveys_configure VALUES(31, 'surveys', 'Pictures Upload', 'Max Survay image height', '', 'MAX_SURVEY_IMAGE_HEIGHT', '200', 1);
INSERT INTO surveys_configure VALUES(32, 'surveys', 'Pictures Upload', 'Allowed MIME types', '', 'OK_MIME_TYPES', 'jpeg jpeg jpg gif png', 1);
INSERT INTO surveys_configure VALUES(33, 'surveys', 'Comments', 'Allow module comments', '', 'ALLOW_MODULE_COMMENTS', '1', 1);
INSERT INTO surveys_configure VALUES(34, 'surveys', 'Front Page', 'Frontpage Nr of columns', '', 'FP_NUM_COLS', '2', 0);



DROP TABLE IF EXISTS surveys_desc;
CREATE TABLE surveys_desc (
  survey_id int(10) NOT NULL,
  `language` varchar(32) NOT NULL,
  title varchar(256) NOT NULL,
  description text NOT NULL,
  meta_title varchar(256) NOT NULL,
  meta_keywords varchar(256) NOT NULL,
  meta_description text NOT NULL,
  seo_link varchar(256) NOT NULL,
  PRIMARY KEY  (survey_id,`language`),
  KEY title (title),
  KEY meta_title (meta_title,meta_keywords),
  KEY meta_title_2 (meta_title),
  KEY meta_keywords (meta_keywords),
  KEY seo_link (seo_link)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;






DROP TABLE IF EXISTS surveys_frontpages;
CREATE TABLE surveys_frontpages (
  frontpage_id int(10) NOT NULL auto_increment,
  survey_id int(10) NOT NULL default '0',
  creation varchar(16) NOT NULL default '',
  author_id int(10) NOT NULL default '0',
  frontpage_status int(1) NOT NULL default '0',
  random int(1) NOT NULL default '0',
  is_default int(1) NOT NULL default '0',
  viewer_group int(10) NOT NULL default '0',
  PRIMARY KEY  (frontpage_id),
  KEY author_id (author_id,frontpage_status,random,is_default,viewer_group)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1;


INSERT INTO surveys_frontpages VALUES(4, 1217440409, '2008.07.31 02:43', 1, 1, 1, 1, 0);



DROP TABLE IF EXISTS surveys_metatags;
CREATE TABLE surveys_metatags (
  lid int(3) NOT NULL auto_increment,
  `language` varchar(20) NOT NULL default 'german',
  title text NOT NULL,
  keywords text NOT NULL,
  description text NOT NULL,
  PRIMARY KEY  (lid),
  KEY `language` (`language`)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1;



INSERT INTO surveys_metatags VALUES(1, 'english', 'Xomol - Polls and Surveys', 'xomol cms,content manager system,cms,surveys,survey,open source,vote,votes,download,anonim,polls,comments', 'Xomol CMS. Survey and Polls Module. Your vote is 100% secret. Express yourself, vote now! ');
INSERT INTO surveys_metatags VALUES(2, 'german', 'Xomol - Meinungsumfragen und Wahlsystem', 'xomol cms,content manager system,cms,umfragen,open source,virtuele einkaufszenter,software entwicklung,freie software,virtuele shop,php,david guttmann,stimmen', 'Xomol CMS. Meinungsumfrage und Wahlsystem Software. Deine Stime ist 100% geheim. Sag deine Meinung.');
INSERT INTO surveys_metatags VALUES(3, 'mexican', 'Xomol - Encuestas y votaciones', 'xomol cms,gestor de contenido,encuestas,votos,open source,estadisticas,Desarrollo de software,votar,anonimo,que opinas,tienda virtual,download', 'Xomol CMS. Modulo de Encuestas. Tu voto 100% secreto. Haz valer tu opinion! Vota ahora!');





DROP TABLE IF EXISTS surveys_options_desc;
CREATE TABLE surveys_options_desc (
  survey_id int(10) NOT NULL,
  option_id int(4) NOT NULL,
  `language` varchar(32) NOT NULL,
  title varchar(128) NOT NULL,
  PRIMARY KEY  (survey_id,option_id,`language`),
  KEY title (title),
  KEY option_id (option_id)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;





DROP TABLE IF EXISTS surveys_positions;
CREATE TABLE surveys_positions (
  position_id int(3) NOT NULL auto_increment,
  position_key varchar(32) NOT NULL default '',
  position_title varchar(32) NOT NULL default '',
  position_status int(1) NOT NULL default '0',
  udeleteable int(1) NOT NULL default '0',
  PRIMARY KEY  (position_id),
  KEY position_status (position_status),
  KEY position_key (position_key),
  KEY udeleteable (udeleteable)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1;


INSERT INTO surveys_positions VALUES(1, 'FP_MAIN_1', 'Main Survey Block', 1, 1);
INSERT INTO surveys_positions VALUES(2, 'FP_MAIN_2', 'Main Frontpage', 1, 1);
INSERT INTO surveys_positions VALUES(3, 'FP_MAIN_3', 'Position 3', 1, 1);
INSERT INTO surveys_positions VALUES(4, 'FP_MAIN_4', 'Position 4', 1, 1);
INSERT INTO surveys_positions VALUES(5, 'FPC_MAIN_1', 'Categories Main', 1, 1);
INSERT INTO surveys_positions VALUES(6, 'FPC_MAIN_2', 'Categories Position 2', 1, 1);
INSERT INTO surveys_positions VALUES(7, 'FPC_MAIN_3', 'Categories Position 3', 1, 1);
INSERT INTO surveys_positions VALUES(8, 'FPC_MAIN_4', 'Categories Position 4', 1, 1);


DROP TABLE IF EXISTS surveys_sessions;
CREATE TABLE surveys_sessions (
  survey_session varchar(32) NOT NULL,
  survey_id int(10) NOT NULL,
  vote_date bigint(14) NOT NULL,
  user_id int(10) NOT NULL,
  ip varchar(29) NOT NULL,
  PRIMARY KEY  (survey_session,survey_id),
  KEY vote_date (vote_date),
  KEY user_id (user_id)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;



DROP TABLE IF EXISTS surveys_user_rights;
CREATE TABLE surveys_user_rights (
  rights_id int(10) NOT NULL auto_increment,
  title varchar(64) NOT NULL,
  description varchar(128) NOT NULL,
  elemental int(1) NOT NULL,
  PRIMARY KEY  (title),
  KEY task_id (rights_id,elemental)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1;


INSERT INTO surveys_user_rights VALUES(100, 'ASYSTEM_ACCESS', 'Access Content Admin Panel', 1);
INSERT INTO surveys_user_rights VALUES(110, 'A_CONFIGURE_ACCESS', 'Access Configuration Administration', 1);
INSERT INTO surveys_user_rights VALUES(111, 'A_CONFIGURE_ADD', 'Add a new configuration key', 1);
INSERT INTO surveys_user_rights VALUES(112, 'A_CONFIGURE_EDIT', 'Edit configuration key', 1);
INSERT INTO surveys_user_rights VALUES(113, 'A_CONFIGURE_DELETE', 'Delete configuration key', 1);
INSERT INTO surveys_user_rights VALUES(130, 'A_METAS_ACCESS', 'Access Metatags Administration', 1);
INSERT INTO surveys_user_rights VALUES(131, 'A_METAS_EDIT', 'Edit main - Survays -  header metatags', 1);
INSERT INTO surveys_user_rights VALUES(150, 'A_POSITIONS_ACCESS', 'Access Positions Administration', 1);
INSERT INTO surveys_user_rights VALUES(151, 'A_POSITIONS_BLOCK_ADD', 'Add a new Block on a position', 1);
INSERT INTO surveys_user_rights VALUES(152, 'A_POSITIONS_BLOCK_EDIT', 'Edit Block on a position', 1);
INSERT INTO surveys_user_rights VALUES(153, 'A_POSITIONS_BLOCK_DEL', 'Delete Block', 1);
INSERT INTO surveys_user_rights VALUES(154, 'A_POSITIONS_POS_ADD', 'Add a new Position', 1);
INSERT INTO surveys_user_rights VALUES(155, 'A_POSITIONS_POS_EDIT', 'Edit Position', 1);
INSERT INTO surveys_user_rights VALUES(156, 'A_POSITIONS_POS_DEL', 'Delete Position', 1);
INSERT INTO surveys_user_rights VALUES(160, 'A_USER_DETAILS_ACCESS', 'Access User Details', 1);
INSERT INTO surveys_user_rights VALUES(161, 'A_USER_RIGHTS_ACCESS', 'Access User Rights', 1);
INSERT INTO surveys_user_rights VALUES(162, 'A_USER_RIGHTS_TASK_ADD', 'Add User Rights', 1);
INSERT INTO surveys_user_rights VALUES(163, 'A_USER_RIGHTS_TASK_EDIT_SAME', 'Edit User Rights for same/higher Group ', 1);
INSERT INTO surveys_user_rights VALUES(164, 'A_USER_RIGHTS_TASK_EDIT_LOW', 'Edit User Rights for same/lower Group ', 1);
INSERT INTO surveys_user_rights VALUES(166, 'A_USER_RIGHTS_TASK2GROUP', 'Edit User Rights (Same UserGroup)', 1);
INSERT INTO surveys_user_rights VALUES(169, 'A_USER_RIGHTS_TASK_VIEW', 'View User Rights tasks', 1);
INSERT INTO surveys_user_rights VALUES(165, 'A_USER_RIGHTS_TASK_OVER', 'Override all User Rights from Groups', 1);
INSERT INTO surveys_user_rights VALUES(167, 'A_USER_RIGHTS_SAME', 'Edit User Rights for same/higher Group', 1);
INSERT INTO surveys_user_rights VALUES(168, 'A_USER_RIGHTS_LOW', 'Edit User Rights for same/lower Group ', 1);
INSERT INTO surveys_user_rights VALUES(202, 'SURVEYS_ADMIN_ACCESS', 'Access Category & Product Administration', 1);
INSERT INTO surveys_user_rights VALUES(203, 'SURVEYS_ADD_OWN', 'Add article (with own user id)', 1);
INSERT INTO surveys_user_rights VALUES(204, 'SURVEYS_ADD_OTHERS', 'Add article (to other user ids)', 1);
INSERT INTO surveys_user_rights VALUES(205, 'SURVEYS_ADD_OTHERS_SAME', 'Add survey to users on the same group', 1);
INSERT INTO surveys_user_rights VALUES(206, 'SURVEYS_ADD_OTHERS_LOW', 'Add survey to subusers', 1);
INSERT INTO surveys_user_rights VALUES(207, 'SURVEYS_ADD_TARG_USER', 'Add a survey exclusivly to a user', 1);
INSERT INTO surveys_user_rights VALUES(208, 'SURVEYS_ADD_TARG_GROUP', 'Add a survey exclusivly to a group', 1);
INSERT INTO surveys_user_rights VALUES(209, 'SURVEYS_EDIT_OWN', 'Edit survey (with own user id)', 1);
INSERT INTO surveys_user_rights VALUES(300, 'SURVEYS_EDIT_OTHERS', 'Edit survey (to other user ids)', 1);
INSERT INTO surveys_user_rights VALUES(301, 'SURVEYS_EDIT_OTHERS_SAME', 'Edit survey to users on the same group', 1);
INSERT INTO surveys_user_rights VALUES(302, 'SURVEYS_EDIT_OTHERS_LOW', 'Edit survey to subusers', 1);
INSERT INTO surveys_user_rights VALUES(303, 'SURVEYS_DEL_OWN', 'Delete survey (with own user id)', 1);
INSERT INTO surveys_user_rights VALUES(304, 'SURVEYS_DEL_OTHERS', 'Delete survey (to other user ids)', 1);
INSERT INTO surveys_user_rights VALUES(305, 'SURVEYS_DEL_OTHERS_SAME', 'Delete survey to users on the same group', 1);
INSERT INTO surveys_user_rights VALUES(306, 'SURVEYS_DEL_OTHERS_LOW', 'Delete survey to subusers', 1);
INSERT INTO surveys_user_rights VALUES(600, 'SURVEYS_LAYOUT_ACCESS', 'Access and Manage Survays Layout', 1);
INSERT INTO surveys_user_rights VALUES(601, 'ALLOW_COMMENTS_STATUS', 'Allow to change comment status', 1);
INSERT INTO surveys_user_rights VALUES(602, 'ALLOW_COMMENTS_ADD', 'Allow user to add comment', 1);



DROP TABLE IF EXISTS surveys_user_rights2groups;
CREATE TABLE surveys_user_rights2groups (
  group_id int(10) NOT NULL,
  user_rights_id int(10) NOT NULL,
  `value` int(1) NOT NULL,
  PRIMARY KEY  (group_id,user_rights_id),
  KEY `value` (`value`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;



INSERT INTO surveys_user_rights2groups VALUES(1, 100, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 100, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 100, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 100, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 100, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 100, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 110, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 110, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 110, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 110, 0);
INSERT INTO surveys_user_rights2groups VALUES(102, 110, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 110, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 111, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 111, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 111, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 111, 0);
INSERT INTO surveys_user_rights2groups VALUES(102, 111, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 111, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 113, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 113, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 113, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 113, 0);
INSERT INTO surveys_user_rights2groups VALUES(102, 113, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 113, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 112, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 112, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 112, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 112, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 112, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 112, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 130, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 130, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 130, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 130, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 130, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 130, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 131, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 131, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 131, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 131, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 131, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 131, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 140, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 140, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 140, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 140, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 140, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 140, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 141, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 141, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 141, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 141, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 141, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 141, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 150, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 150, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 150, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 150, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 150, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 150, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 151, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 151, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 151, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 151, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 151, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 151, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 153, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 153, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 153, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 153, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 153, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 153, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 152, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 152, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 152, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 152, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 152, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 152, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 154, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 154, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 154, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 154, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 154, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 154, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 156, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 156, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 156, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 156, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 156, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 156, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 155, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 155, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 155, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 155, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 155, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 155, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 160, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 160, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 160, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 160, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 160, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 160, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 161, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 161, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 161, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 161, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 161, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 161, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 168, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 168, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 168, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 168, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 168, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 168, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 167, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 167, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 167, 0);
INSERT INTO surveys_user_rights2groups VALUES(101, 167, 0);
INSERT INTO surveys_user_rights2groups VALUES(102, 167, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 167, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 166, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 166, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 166, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 166, 0);
INSERT INTO surveys_user_rights2groups VALUES(102, 166, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 166, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 162, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 162, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 162, 0);
INSERT INTO surveys_user_rights2groups VALUES(101, 162, 0);
INSERT INTO surveys_user_rights2groups VALUES(102, 162, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 162, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 164, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 164, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 164, 0);
INSERT INTO surveys_user_rights2groups VALUES(101, 164, 0);
INSERT INTO surveys_user_rights2groups VALUES(102, 164, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 164, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 163, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 163, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 163, 0);
INSERT INTO surveys_user_rights2groups VALUES(101, 163, 0);
INSERT INTO surveys_user_rights2groups VALUES(102, 163, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 163, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 165, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 165, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 165, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 165, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 165, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 165, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 202, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 202, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 202, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 202, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 202, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 202, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 204, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 204, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 204, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 204, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 204, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 204, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 206, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 206, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 206, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 206, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 206, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 206, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 205, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 205, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 205, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 205, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 205, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 205, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 203, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 203, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 203, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 203, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 203, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 203, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 208, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 208, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 208, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 208, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 208, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 208, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 207, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 207, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 207, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 207, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 207, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 207, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 304, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 304, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 304, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 304, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 304, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 304, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 306, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 306, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 306, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 306, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 306, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 306, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 305, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 305, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 305, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 305, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 305, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 305, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 303, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 303, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 303, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 303, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 303, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 303, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 300, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 300, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 300, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 300, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 300, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 300, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 302, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 302, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 302, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 302, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 302, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 302, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 301, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 301, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 301, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 301, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 301, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 301, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 209, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 209, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 209, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 209, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 209, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 209, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 600, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 600, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 600, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 600, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 600, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 600, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 169, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 169, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 169, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 169, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 169, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 169, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 601, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 601, 0);
INSERT INTO surveys_user_rights2groups VALUES(100, 601, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 601, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 601, 0);
INSERT INTO surveys_user_rights2groups VALUES(200, 601, 0);
INSERT INTO surveys_user_rights2groups VALUES(1, 602, 1);
INSERT INTO surveys_user_rights2groups VALUES(2, 602, 1);
INSERT INTO surveys_user_rights2groups VALUES(100, 602, 1);
INSERT INTO surveys_user_rights2groups VALUES(101, 602, 1);
INSERT INTO surveys_user_rights2groups VALUES(102, 602, 1);
INSERT INTO surveys_user_rights2groups VALUES(200, 602, 1);


DROP TABLE IF EXISTS surveys_user_rights2users;
CREATE TABLE surveys_user_rights2users (
  user_id int(10) NOT NULL,
  user_rights_id int(10) NOT NULL,
  `value` int(1) NOT NULL,
  PRIMARY KEY  (user_id,user_rights_id),
  KEY `value` (`value`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;


DROP TABLE IF EXISTS surveys_user_rights_desc;
CREATE TABLE surveys_user_rights_desc (
  rights_id varchar(10) NOT NULL,
  `language` varchar(32) NOT NULL,
  description varchar(128) NOT NULL,
  PRIMARY KEY  (rights_id,`language`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;



INSERT INTO themes_blocks VALUES(254, 1191298880, 'surveys', 'surveys', '1', 0, 2);
INSERT INTO modules VALUES('surveys', 1, 1, ',1,100,101', 0, 0, '');
INSERT INTO modules_desc VALUES('surveys', 'Encuestas', 'mexican');
INSERT INTO modules_desc VALUES('surveys', 'Surveys', 'english');
INSERT INTO modules_desc VALUES('surveys', 'Meinungsumfragen', 'german');

UPDATE modules SET  active='1' WHERE title='surveys'  );
UPDATE modules SET  active_root='1' WHERE title='surveys'  );
UPDATE modules_desc SET  module_custom_name='Encuestas' WHERE title='surveys' AND language='mexican' );
UPDATE modules_desc SET  module_custom_name='Surveys' WHERE title='surveys' AND language='english' );
UPDATE modules_desc SET  module_custom_name='Meinungsumfragen' WHERE title='surveys' AND language='german' );


